@@ -65,7 +65,7 @@ pub fn expand_function(
     Ok(quote! {
         #doc
         pub fn #name(&self #input) -> #result {
-            Contract::method_hash(&self.fuel_client, &self.compiled,
+            Contract::method_hash(&self.fuel_client, self.contract_id,
                 #tokenized_signature, #output_params_token, #arg).expect("method not found (this should never happen)")
         }
     })
@@ -114,28 +114,15 @@ fn expand_function_arguments(
     custom_enums: &HashMap<String, Property>,
     custom_structs: &HashMap<String, Property>,
 ) -> Result<(TokenStream, TokenStream), Error> {
-    let mut args = Vec::with_capacity(fun.inputs.len());
-    let mut call_args = Vec::with_capacity(fun.inputs.len());
+    let mut args = vec![];
+    let mut call_args = vec![];
 
-    // For each [`Property`] in a function input we expand:
-    // 1. The name of the argument;
-    // 2. The type of the argument;
     for (i, param) in fun.inputs.iter().enumerate() {
-        // This is a (likely) temporary workaround the fact that
-        // Sway ABI functions require gas, coin amount, and color arguments
-        // pre-pending the user-defined function arguments.
-        // Since these values (gas, coin, color) are configured elsewhere when
-        // creating a contract instance in the SDK, it would be noisy to keep them
-        // in the signature of the function that we're expanding here.
-        // It's the difference between being forced to write:
-        // contract_instance.increment_counter($gas, $coin, $color, 42)
-        // versus simply writing:
-        // contract_instance.increment_counter(42)
+        // For each [`Property`] in a function input we expand:
+        // 1. The name of the argument;
+        // 2. The type of the argument;
         // Note that _any_ significant change in the way the JSON ABI is generated
         // could affect this function expansion.
-        if param.name == "gas_" || param.name == "amount_" || param.name == "color_" {
-            continue;
-        }
         // TokenStream representing the name of the argument
         let name = expand_input_name(i, &param.name);
 
@@ -181,10 +168,7 @@ fn expand_function_arguments(
     // It'll look like `&[my_arg.into_token(), another_arg.into_token()]`
     // as the [`Contract`] `method_hash` function expects a slice of Tokens
     // in order to encode the call.
-    let call_args = match call_args.len() {
-        0 => quote! { () },
-        _ => quote! { &[ #(#call_args.into_token(), )* ] },
-    };
+    let call_args = quote! { &[ #(#call_args.into_token(), )* ] };
 
     Ok((args, call_args))
 }
@@ -249,21 +233,21 @@ fn expand_input_param(
 mod tests {
     use super::*;
     use std::str::FromStr;
-    // --- expand_function ---
     #[test]
     fn test_expand_function_simple() {
-        let f = Function {
+        let mut the_function = Function {
             type_field: "unused".to_string(),
-            inputs: vec![Property {
-                name: String::from("bimbam"),
-                type_field: String::from("bool"),
-                components: None,
-            }],
+            inputs: vec![],
             name: "HelloWorld".to_string(),
             outputs: vec![],
         };
+        the_function.inputs.push(Property {
+            name: String::from("bimbam"),
+            type_field: String::from("bool"),
+            components: None,
+        });
         let result = expand_function(
-            &f,
+            &the_function,
             &ABIParser::new(),
             &Default::default(),
             &Default::default(),
@@ -274,10 +258,10 @@ mod tests {
 pub fn HelloWorld(&self, bimbam: bool) -> ContractCall<()> {
     Contract::method_hash(
         &self.fuel_client,
-        &self.compiled,
+        self.contract_id,
         [0, 0, 0, 0, 151, 212, 222, 69],
         &[],
-        &[bimbam.into_token(), ]
+        &[bimbam.into_token() ,]
     )
     .expect("method not found (this should never happen)")
 }
@@ -288,43 +272,10 @@ pub fn HelloWorld(&self, bimbam: bool) -> ContractCall<()> {
     }
     #[test]
     fn test_expand_function_complex() {
-        let the_function = Function {
+        let mut the_function = Function {
             type_field: "function".to_string(),
             name: "hello_world".to_string(),
-            inputs: vec![
-                Property {
-                    name: String::from("input"),
-                    type_field: String::from("struct BimBapStruct"),
-                    components: Some(vec![
-                        Property {
-                            name: String::from("Meat"),
-                            type_field: String::from("bool"),
-                            components: None,
-                        },
-                        Property {
-                            name: String::from("Rice"),
-                            type_field: String::from("u64"),
-                            components: None,
-                        },
-                    ]),
-                },
-                Property {
-                    name: String::from("another_input"),
-                    type_field: String::from("enum BurgundyBeefEnum"),
-                    components: Some(vec![
-                        Property {
-                            name: String::from("Beef"),
-                            type_field: String::from("bool"),
-                            components: None,
-                        },
-                        Property {
-                            name: String::from("BurgundyWine"),
-                            type_field: String::from("u64"),
-                            components: None,
-                        },
-                    ]),
-                },
-            ],
+            inputs: vec![],
             outputs: vec![
                 Property {
                     name: String::from("notused"),
@@ -360,12 +311,28 @@ pub fn HelloWorld(&self, bimbam: bool) -> ContractCall<()> {
                 },
             ],
         };
+        the_function.inputs.push(Property {
+            name: String::from("the_only_allowed_input"),
+            type_field: String::from("struct BurgundyBeefStruct"),
+            components: Some(vec![
+                Property {
+                    name: String::from("Beef"),
+                    type_field: String::from("bool"),
+                    components: None,
+                },
+                Property {
+                    name: String::from("BurgundyWine"),
+                    type_field: String::from("u64"),
+                    components: None,
+                },
+            ]),
+        });
         let mut custom_structs = HashMap::new();
         custom_structs.insert(
-            "BimBapStruct".to_string(),
+            "BurgundyBeefStruct".to_string(),
             Property {
                 name: "unused".to_string(),
-                type_field: "struct BimBapStruct".to_string(),
+                type_field: "struct SomeWeirdFrenchCuisine".to_string(),
                 components: None,
             },
         );
@@ -386,33 +353,24 @@ pub fn HelloWorld(&self, bimbam: bool) -> ContractCall<()> {
                 components: None,
             },
         );
-        custom_enums.insert(
-            "BurgundyBeefEnum".to_string(),
-            Property {
-                name: "unused".to_string(),
-                type_field: "enum BurgundyBeefEnum".to_string(),
-                components: None,
-            },
-        );
         let abi_parser = ABIParser::new();
         let result = expand_function(&the_function, &abi_parser, &custom_enums, &custom_structs);
         // Some more editing was required because it is not rustfmt-compatible (adding/removing parentheses or commas)
         let expected = TokenStream::from_str(
             r#"
-#[doc = "Calls the contract's `hello_world` (0x000000004d65f217) function"]
+#[doc = "Calls the contract's `hello_world` (0x0000000076b25a24) function"]
 pub fn hello_world(
     &self,
-    input: BimBapStruct,
-    another_input: BurgundyBeefEnum
+    the_only_allowed_input: SomeWeirdFrenchCuisine
 ) -> ContractCall<((bool , u64 ,) , (bool, u64 ,))> {
     Contract::method_hash(
         &self.fuel_client,
-        &self.compiled,
-        [0, 0, 0, 0, 77, 101, 242, 23],
+        self.contract_id,
+        [0, 0, 0, 0, 118, 178, 90, 36],
         &[
             ParamType::Struct(vec![ParamType::Bool, ParamType::U64]),
             ParamType::Enum([Bool , U64])] , 
-            &[input.into_token(), another_input.into_token(),]
+            &[the_only_allowed_input . into_token () ,]
     )
     .expect("method not found (this should never happen)")
 }
@@ -590,84 +548,69 @@ pub fn hello_world(
 
     // --- expand_function_argument ---
     #[test]
-    fn test_expand_function_arguments_workaround() {
-        let function = Function {
+    fn test_expand_function_arguments() {
+        let hm: HashMap<String, Property> = HashMap::new();
+        let the_argument = Property {
+            name: "some_argument".to_string(),
+            type_field: String::from("u32"),
+            components: None,
+        };
+
+        // All arguments are here
+        let mut the_function = Function {
             type_field: "".to_string(),
-            inputs: vec![
-                Property {
-                    name: "gas_".to_string(),
-                    type_field: String::from("bool"),
-                    components: None,
-                },
-                Property {
-                    name: "amount_".to_string(),
-                    type_field: String::from("u64"),
-                    components: None,
-                },
-                Property {
-                    name: "color_".to_string(),
-                    type_field: String::from("u32"),
-                    components: None,
-                },
-            ],
+            inputs: vec![],
             name: "".to_string(),
             outputs: vec![],
         };
-        let hm: HashMap<String, Property> = HashMap::new();
-        let result = expand_function_arguments(&function, &hm, &hm);
+        the_function.inputs.push(the_argument);
+
+        let result = expand_function_arguments(&the_function, &hm, &hm);
         let (args, call_args) = result.unwrap();
         let result = format!("({},{})", args, call_args);
-        assert_eq!(result, "(,())");
+        let expected = "(, some_argument : u32,& [some_argument . into_token () ,])";
+        assert_eq!(result, expected);
     }
     #[test]
     fn test_expand_function_arguments_primitive() {
-        let function = Function {
+        let hm: HashMap<String, Property> = HashMap::new();
+        let mut the_function = Function {
             type_field: "function".to_string(),
-            inputs: vec![
-                Property {
-                    name: "bim_bam".to_string(),
-                    type_field: String::from("bool"),
-                    components: None,
-                },
-                Property {
-                    name: "".to_string(),
-                    type_field: String::from("u64"),
-                    components: None,
-                },
-            ],
+            inputs: vec![],
             name: "pip_pop".to_string(),
             outputs: vec![],
         };
-        let hm: HashMap<String, Property> = HashMap::new();
-        let result = expand_function_arguments(&function, &hm, &hm);
+
+        the_function.inputs.push(Property {
+            name: "bim_bam".to_string(),
+            type_field: String::from("u64"),
+            components: None,
+        });
+        let result = expand_function_arguments(&the_function, &hm, &hm);
         let (args, call_args) = result.unwrap();
         let result = format!("({},{})", args, call_args);
-        assert_eq!(
-            result,
-            "(, bim_bam : bool , p1 : u64,& [bim_bam . into_token () , p1 . into_token () ,])"
-        );
+        assert_eq!(result, "(, bim_bam : u64,& [bim_bam . into_token () ,])");
+
+        the_function.inputs[0].name = String::from("");
+        let result = expand_function_arguments(&the_function, &hm, &hm);
+        let (args, call_args) = result.unwrap();
+        let result = format!("({},{})", args, call_args);
+        assert_eq!(result, "(, p0 : u64,& [p0 . into_token () ,])");
     }
     #[test]
     fn test_expand_function_arguments_composite() {
-        let function = Function {
+        let mut function = Function {
             type_field: "zig_zag".to_string(),
-            inputs: vec![
-                Property {
-                    name: "bim_bam".to_string(),
-                    type_field: String::from("struct CarMaker"),
-                    // Not parsed, so can be empty but not None
-                    components: Some(vec![]),
-                },
-                Property {
-                    name: "pim_poum".to_string(),
-                    type_field: String::from("enum Bank"),
-                    // Not parsed, so can be empty but not None
-                    components: Some(vec![]),
-                },
-            ],
+            inputs: vec![],
             name: "PipPopFunction".to_string(),
             outputs: vec![],
         };
+        function.inputs.push(Property {
+            name: "bim_bam".to_string(),
+            type_field: String::from("struct CarMaker"),
+            // Not parsed, so can be empty but not None
+            components: Some(vec![]),
+        });
         let mut custom_structs = HashMap::new();
         custom_structs.insert(
             "CarMaker".to_string(),
@@ -678,19 +621,10 @@ pub fn hello_world(
             },
         );
 
-        let mut custom_enums = HashMap::new();
-        custom_enums.insert(
-            "Bank".to_string(),
-            Property {
-                name: "unused".to_string(),
-                type_field: "enum Bank".to_string(),
-                components: None,
-            },
-        );
-        let result = expand_function_arguments(&function, &custom_enums, &custom_structs);
+        let result = expand_function_arguments(&function, &custom_structs, &custom_structs);
         let (args, call_args) = result.unwrap();
         let result = format!("({},{})", args, call_args);
-        let expected = r#"(, bim_bam : CarMaker , pim_poum : Bank,& [bim_bam . into_token () , pim_poum . into_token () ,])"#;
+        let expected = r#"(, bim_bam : CarMaker,& [bim_bam . into_token () ,])"#;
         assert_eq!(result, expected);
     }
 
